Generic functions with multiple dispatch for handling clinical content. These use S7's method dispatch system to provide polymorphic behavior based on the class of arguments.
Generic functions with multiple dispatch for handling clinical content. These use S7's method dispatch system to provide polymorphic behavior based on the class of arguments.