Validates that x is within the specified range (exclusive bounds). NA values are rejected.
Usage
assert_in_range(x, lower = -Inf, upper = Inf, arg = deparse(substitute(x)))Validates that x is within the specified range (exclusive bounds). NA values are rejected.
assert_in_range(x, lower = -Inf, upper = Inf, arg = deparse(substitute(x)))