Skip to contents

Internal helper to build a single row of data for the study characteristics table.

Usage

.build_study_characteristic_row(study, include_metadata)

Arguments

study

Study object, list, or data frame containing study information

include_metadata

Logical, include metadata columns

Value

List of row data with all column values