Functions for translating table headers, labels, and other text elements between languages. Essential for German HTA (G-BA/AMNOG) dossiers which require German table headers and labels.
Functions for translating table headers, labels, and other text elements between languages. Essential for German HTA (G-BA/AMNOG) dossiers which require German table headers and labels.