Build Study Characteristic Row
Source:R/evidence_summary_table.R
dot-build_study_characteristic_row.RdInternal helper to build a single row of data for the study characteristics table.

R/evidence_summary_table.R
dot-build_study_characteristic_row.RdInternal helper to build a single row of data for the study characteristics table.